# [Django Admin Star](https://github.com/app-generator/django-admin-star)

Modern template for **Django Admin Interface** coded on top of **[Star Admin](https://github.com/app-generator/django-admin-star)**, an open-source `Bootstrap 5` design from [BootstrapDash](https://www.bootstrapdash.com?ref=23).

> Actively supported by [AppSeed](https://appseed.us/) via `Email` and `Discord`.

<br>

**Links & Resources**

- UI Kit: [Star Admin BS5](https://www.bootstrapdash.com/product/star-admin-free?ref=23) by `BootstrapDash`
- [Django Admin Star](https://django-star-admin.appseed-srv1.com/) - `LIVE Demo`
- [Django Admin Star](https://github.com/app-generator/django-admin-star_p) - `playground project`

<br />

![Star Admin - Full-Stack Starter generated by AppSeed.](https://user-images.githubusercontent.com/51070104/168732392-51748c85-f2c2-45ad-978c-2b64e52292e2.png)

<br />

## Why `Django Admin Star`

- Modern `Bootstrap 5` Design
- `Responsive Interface`
- `Minimal Template` overriding
- `Easy integration`

**Star Admin** is a free admin dashboard template built with **[Bootstrap 5](https://www.admin-dashboards.com/bootstrap-5-templates/)**. We took the original `Star Admin` and gave it a design overhaul along with newly written code to create our best template yet. This is a modern-looking dashboard with a clean and elegant design. 

<br />

## How to use it

<br />

> **Install the package** via `PIP` 

```bash
$ pip install django-admin-star
// OR
$ pip install git+https://github.com/app-generator/django-admin-star.git
```

<br />

> Add `admin_star` application to the `INSTALLED_APPS` setting of your Django project `settings.py` file (note it should be before `django.contrib.admin`):

```python
    INSTALLED_APPS = (
        ...
        'admin_star.apps.AdminStarConfig',
        'django.contrib.admin',
    )
```

<br />

> Add `LOGIN_REDIRECT_URL` and `EMAIL_BACKEND` of your Django project `settings.py` file:

```python
    LOGIN_REDIRECT_URL = '/'
    # EMAIL_BACKEND = 'django.core.mail.backends.smtp.EmailBackend'
    EMAIL_BACKEND = 'django.core.mail.backends.console.EmailBackend'
```

<br />

> Add `admin_star` urls in your Django Project `urls.py` file

```python
    from django.urls import path, include

    urlpatterns = [
        ...
        path('', include('admin_star.urls')),
    ]
```

<br />

> **Collect static** if you are in `production environment`:

```bash
$ python manage.py collectstatic
```

<br />

> **Start the app**

```bash
$ # Set up the database
$ python manage.py makemigrations
$ python manage.py migrate
$
$ # Create the superuser
$ python manage.py createsuperuser
$
$ # Start the application (development mode)
$ python manage.py runserver # default port 8000
```

Access the `admin` section in the browser: `http://127.0.0.1:8000/`

<br />

## Screenshots

Star Admin 2 Free comes with a clean and well-commented code that makes it easy to work with the template. The UI is well crafted, with all the components neatly and carefully designed and arranged within the template.

![Django Star Admin, Charts page - Full-Stack Starter generated by AppSeed.](https://user-images.githubusercontent.com/51070104/206991492-b1e6e804-da2c-4d60-8602-f14b4823b8c3.jpg) 

<br />

> [Django Admin Star](https://github.com/app-generator/django-admin-star) - `UI Components`

![Django Star Admin, UI Components - Full-Stack Starter generated by AppSeed.](https://user-images.githubusercontent.com/51070104/206991605-e1656de1-06fb-4188-a939-e35d10dede00.jpg)

<br />

> [Django Admin Star](https://github.com/app-generator/django-admin-star) - `Dashboard`

![Django Star Admin, Dashboard - Full-Stack Starter generated by AppSeed.](https://user-images.githubusercontent.com/51070104/206991715-a39ddcb7-a3c7-458d-9830-3cf6c776c2b6.jpg) 

<br />

---
[Django Admin Star](https://github.com/app-generator/django-admin-star) - Modern Admin Interface provided by **[AppSeed](https://appseed.us/)**
